@@ -104,12 +104,12 @@ around app_build => sub ( $orig, $self ) {
         my $res = try {
             P->file->mkpath( $self->alien_dir );
 
-            P->sys->system( q[wget -O - http://download.redis.io/releases/redis-] . $self->redis_ver . q[.tar.gz | tar -C ] . $self->alien_dir . q[ --strip-components=1 -xzvf -] );
+            P->pm->run_check( q[wget -O - http://download.redis.io/releases/redis-] . $self->redis_ver . q[.tar.gz | tar -C ] . $self->alien_dir . q[ --strip-components=1 -xzvf -] );
 
             {
                 my $chdir_guard = P->file->chdir( $self->alien_dir ) or die;
 
-                P->sys->system( q[make], q[-j] . P->sys->cpus_num );
+                P->pm->run_check( q[make], q[-j] . P->sys->cpus_num );
             }
 
             return 1;
